@@ -256,20 +256,20 @@ def test_question_service_client_client_options(
     # unsupported value.
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "Unsupported"}):
         with pytest.raises(MutualTLSChannelError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case GOOGLE_API_USE_CLIENT_CERTIFICATE has unsupported value.
     with mock.patch.dict(
         os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "Unsupported"}
     ):
         with pytest.raises(ValueError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case quota_project_id is provided
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -338,7 +338,7 @@ def test_question_service_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(transport=transport_name, client_options=options)
+            client = client_class(client_options=options, transport=transport_name)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -415,6 +415,87 @@ def test_question_service_client_mtls_env_auto(
                 )
 
 
+@pytest.mark.parametrize(
+    "client_class", [QuestionServiceClient, QuestionServiceAsyncClient]
+)
+@mock.patch.object(
+    QuestionServiceClient,
+    "DEFAULT_ENDPOINT",
+    modify_default_endpoint(QuestionServiceClient),
+)
+@mock.patch.object(
+    QuestionServiceAsyncClient,
+    "DEFAULT_ENDPOINT",
+    modify_default_endpoint(QuestionServiceAsyncClient),
+)
+def test_question_service_client_get_mtls_endpoint_and_cert_source(client_class):
+    mock_client_cert_source = mock.Mock()
+
+    # Test the case GOOGLE_API_USE_CLIENT_CERTIFICATE is "true".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        mock_api_endpoint = "foo"
+        options = client_options.ClientOptions(
+            client_cert_source=mock_client_cert_source, api_endpoint=mock_api_endpoint
+        )
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source(
+            options
+        )
+        assert api_endpoint == mock_api_endpoint
+        assert cert_source == mock_client_cert_source
+
+    # Test the case GOOGLE_API_USE_CLIENT_CERTIFICATE is "false".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "false"}):
+        mock_client_cert_source = mock.Mock()
+        mock_api_endpoint = "foo"
+        options = client_options.ClientOptions(
+            client_cert_source=mock_client_cert_source, api_endpoint=mock_api_endpoint
+        )
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source(
+            options
+        )
+        assert api_endpoint == mock_api_endpoint
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "never".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "never"}):
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+        assert api_endpoint == client_class.DEFAULT_ENDPOINT
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "always".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "always"}):
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+        assert api_endpoint == client_class.DEFAULT_MTLS_ENDPOINT
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "auto" and default cert doesn't exist.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        with mock.patch(
+            "google.auth.transport.mtls.has_default_client_cert_source",
+            return_value=False,
+        ):
+            api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+            assert api_endpoint == client_class.DEFAULT_ENDPOINT
+            assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "auto" and default cert exists.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        with mock.patch(
+            "google.auth.transport.mtls.has_default_client_cert_source",
+            return_value=True,
+        ):
+            with mock.patch(
+                "google.auth.transport.mtls.default_client_cert_source",
+                return_value=mock_client_cert_source,
+            ):
+                (
+                    api_endpoint,
+                    cert_source,
+                ) = client_class.get_mtls_endpoint_and_cert_source()
+                assert api_endpoint == client_class.DEFAULT_MTLS_ENDPOINT
+                assert cert_source == mock_client_cert_source
+
+
 @pytest.mark.parametrize(
     "client_class,transport_class,transport_name",
     [
@@ -433,7 +514,7 @@ def test_question_service_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -447,24 +528,31 @@ def test_question_service_client_client_options_scopes(
 
 
 @pytest.mark.parametrize(
-    "client_class,transport_class,transport_name",
+    "client_class,transport_class,transport_name,grpc_helpers",
     [
-        (QuestionServiceClient, transports.QuestionServiceGrpcTransport, "grpc"),
+        (
+            QuestionServiceClient,
+            transports.QuestionServiceGrpcTransport,
+            "grpc",
+            grpc_helpers,
+        ),
         (
             QuestionServiceAsyncClient,
             transports.QuestionServiceGrpcAsyncIOTransport,
             "grpc_asyncio",
+            grpc_helpers_async,
         ),
     ],
 )
 def test_question_service_client_client_options_credentials_file(
-    client_class, transport_class, transport_name
+    client_class, transport_class, transport_name, grpc_helpers
 ):
     # Check the case credentials file is provided.
     options = client_options.ClientOptions(credentials_file="credentials.json")
+
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -497,9 +585,74 @@ def test_question_service_client_client_options_from_dict():
         )
 
 
-def test_get_question(
-    transport: str = "grpc", request_type=question_service.GetQuestionRequest
+@pytest.mark.parametrize(
+    "client_class,transport_class,transport_name,grpc_helpers",
+    [
+        (
+            QuestionServiceClient,
+            transports.QuestionServiceGrpcTransport,
+            "grpc",
+            grpc_helpers,
+        ),
+        (
+            QuestionServiceAsyncClient,
+            transports.QuestionServiceGrpcAsyncIOTransport,
+            "grpc_asyncio",
+            grpc_helpers_async,
+        ),
+    ],
+)
+def test_question_service_client_create_channel_credentials_file(
+    client_class, transport_class, transport_name, grpc_helpers
 ):
+    # Check the case credentials file is provided.
+    options = client_options.ClientOptions(credentials_file="credentials.json")
+
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file="credentials.json",
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+        )
+
+    # test that the credentials from file are saved and used as the credentials.
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel"
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        file_creds = ga_credentials.AnonymousCredentials()
+        load_creds.return_value = (file_creds, None)
+        adc.return_value = (creds, None)
+        client = client_class(client_options=options, transport=transport_name)
+        create_channel.assert_called_with(
+            "dataqna.googleapis.com:443",
+            credentials=file_creds,
+            credentials_file=None,
+            quota_project_id=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=None,
+            default_host="dataqna.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize("request_type", [question_service.GetQuestionRequest, dict,])
+def test_get_question(request_type, transport: str = "grpc"):
     client = QuestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -534,10 +687,6 @@ def test_get_question(
     assert response.user_email == "user_email_value"
 
 
-def test_get_question_from_dict():
-    test_get_question(request_type=dict)
-
-
 def test_get_question_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -664,7 +813,9 @@ def test_get_question_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 def test_get_question_flattened_error():
@@ -698,7 +849,9 @@ async def test_get_question_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -715,9 +868,10 @@ async def test_get_question_flattened_error_async():
         )
 
 
-def test_create_question(
-    transport: str = "grpc", request_type=question_service.CreateQuestionRequest
-):
+@pytest.mark.parametrize(
+    "request_type", [question_service.CreateQuestionRequest, dict,]
+)
+def test_create_question(request_type, transport: str = "grpc"):
     client = QuestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -752,10 +906,6 @@ def test_create_question(
     assert response.user_email == "user_email_value"
 
 
-def test_create_question_from_dict():
-    test_create_question(request_type=dict)
-
-
 def test_create_question_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -886,8 +1036,12 @@ def test_create_question_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
-        assert args[0].question == gcd_question.Question(name="name_value")
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
+        arg = args[0].question
+        mock_val = gcd_question.Question(name="name_value")
+        assert arg == mock_val
 
 
 def test_create_question_flattened_error():
@@ -927,8 +1081,12 @@ async def test_create_question_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
-        assert args[0].question == gcd_question.Question(name="name_value")
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
+        arg = args[0].question
+        mock_val = gcd_question.Question(name="name_value")
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -947,9 +1105,10 @@ async def test_create_question_flattened_error_async():
         )
 
 
-def test_execute_question(
-    transport: str = "grpc", request_type=question_service.ExecuteQuestionRequest
-):
+@pytest.mark.parametrize(
+    "request_type", [question_service.ExecuteQuestionRequest, dict,]
+)
+def test_execute_question(request_type, transport: str = "grpc"):
     client = QuestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -984,10 +1143,6 @@ def test_execute_question(
     assert response.user_email == "user_email_value"
 
 
-def test_execute_question_from_dict():
-    test_execute_question(request_type=dict)
-
-
 def test_execute_question_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1117,8 +1272,12 @@ def test_execute_question_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
-        assert args[0].interpretation_index == 2159
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
+        arg = args[0].interpretation_index
+        mock_val = 2159
+        assert arg == mock_val
 
 
 def test_execute_question_flattened_error():
@@ -1156,8 +1315,12 @@ async def test_execute_question_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
-        assert args[0].interpretation_index == 2159
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
+        arg = args[0].interpretation_index
+        mock_val = 2159
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1176,9 +1339,10 @@ async def test_execute_question_flattened_error_async():
         )
 
 
-def test_get_user_feedback(
-    transport: str = "grpc", request_type=question_service.GetUserFeedbackRequest
-):
+@pytest.mark.parametrize(
+    "request_type", [question_service.GetUserFeedbackRequest, dict,]
+)
+def test_get_user_feedback(request_type, transport: str = "grpc"):
     client = QuestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1211,10 +1375,6 @@ def test_get_user_feedback(
     assert response.rating == user_feedback.UserFeedback.UserFeedbackRating.POSITIVE
 
 
-def test_get_user_feedback_from_dict():
-    test_get_user_feedback(request_type=dict)
-
-
 def test_get_user_feedback_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1350,7 +1510,9 @@ def test_get_user_feedback_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 def test_get_user_feedback_flattened_error():
@@ -1388,7 +1550,9 @@ async def test_get_user_feedback_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].name == "name_value"
+        arg = args[0].name
+        mock_val = "name_value"
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1405,9 +1569,10 @@ async def test_get_user_feedback_flattened_error_async():
         )
 
 
-def test_update_user_feedback(
-    transport: str = "grpc", request_type=question_service.UpdateUserFeedbackRequest
-):
+@pytest.mark.parametrize(
+    "request_type", [question_service.UpdateUserFeedbackRequest, dict,]
+)
+def test_update_user_feedback(request_type, transport: str = "grpc"):
     client = QuestionServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1440,10 +1605,6 @@ def test_update_user_feedback(
     assert response.rating == gcd_user_feedback.UserFeedback.UserFeedbackRating.POSITIVE
 
 
-def test_update_user_feedback_from_dict():
-    test_update_user_feedback(request_type=dict)
-
-
 def test_update_user_feedback_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1588,10 +1749,12 @@ def test_update_user_feedback_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].user_feedback == gcd_user_feedback.UserFeedback(
-            name="name_value"
-        )
-        assert args[0].update_mask == field_mask_pb2.FieldMask(paths=["paths_value"])
+        arg = args[0].user_feedback
+        mock_val = gcd_user_feedback.UserFeedback(name="name_value")
+        assert arg == mock_val
+        arg = args[0].update_mask
+        mock_val = field_mask_pb2.FieldMask(paths=["paths_value"])
+        assert arg == mock_val
 
 
 def test_update_user_feedback_flattened_error():
@@ -1634,10 +1797,12 @@ async def test_update_user_feedback_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].user_feedback == gcd_user_feedback.UserFeedback(
-            name="name_value"
-        )
-        assert args[0].update_mask == field_mask_pb2.FieldMask(paths=["paths_value"])
+        arg = args[0].user_feedback
+        mock_val = gcd_user_feedback.UserFeedback(name="name_value")
+        assert arg == mock_val
+        arg = args[0].update_mask
+        mock_val = field_mask_pb2.FieldMask(paths=["paths_value"])
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1676,6 +1841,23 @@ def test_credentials_transport_error():
             transport=transport,
         )
 
+    # It is an error to provide an api_key and a transport instance.
+    transport = transports.QuestionServiceGrpcTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    options = client_options.ClientOptions()
+    options.api_key = "api_key"
+    with pytest.raises(ValueError):
+        client = QuestionServiceClient(client_options=options, transport=transport,)
+
+    # It is an error to provide an api_key and a credential.
+    options = mock.Mock()
+    options.api_key = "api_key"
+    with pytest.raises(ValueError):
+        client = QuestionServiceClient(
+            client_options=options, credentials=ga_credentials.AnonymousCredentials()
+        )
+
     # It is an error to provide scopes and a transport instance.
     transport = transports.QuestionServiceGrpcTransport(
         credentials=ga_credentials.AnonymousCredentials(),
@@ -2198,7 +2380,7 @@ def test_parse_common_location_path():
     assert expected == actual
 
 
-def test_client_withDEFAULT_CLIENT_INFO():
+def test_client_with_default_client_info():
     client_info = gapic_v1.client_info.ClientInfo()
 
     with mock.patch.object(
@@ -2263,3 +2445,33 @@ def test_client_ctx():
             with client:
                 pass
             close.assert_called()
+
+
+@pytest.mark.parametrize(
+    "client_class,transport_class",
+    [
+        (QuestionServiceClient, transports.QuestionServiceGrpcTransport),
+        (QuestionServiceAsyncClient, transports.QuestionServiceGrpcAsyncIOTransport),
+    ],
+)
+def test_api_key_credentials(client_class, transport_class):
+    with mock.patch.object(
+        google.auth._default, "get_api_key_credentials", create=True
+    ) as get_api_key_credentials:
+        mock_cred = mock.Mock()
+        get_api_key_credentials.return_value = mock_cred
+        options = client_options.ClientOptions()
+        options.api_key = "api_key"
+        with mock.patch.object(transport_class, "__init__") as patched:
+            patched.return_value = None
+            client = client_class(client_options=options)
+            patched.assert_called_once_with(
+                credentials=mock_cred,
+                credentials_file=None,
+                host=client.DEFAULT_ENDPOINT,
+                scopes=None,
+                client_cert_source_for_mtls=None,
+                quota_project_id=None,
+                client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
+            )
